<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es">
<context>
    <name>ActionManager</name>
    <message>
        <location filename="../actionmanager.cpp" line="38"/>
        <source>&amp;Play</source>
        <translation>&amp;Reproducir</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="38"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="39"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pausar</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="39"/>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="40"/>
        <source>&amp;Stop</source>
        <translation>&amp;Detener</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="40"/>
        <source>V</source>
        <translation>V</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="41"/>
        <source>&amp;Previous</source>
        <translation>&amp;Anterior</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="41"/>
        <source>Z</source>
        <translation>Z</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="42"/>
        <source>&amp;Next</source>
        <translation>&amp;Siguiente</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="42"/>
        <source>B</source>
        <translation>B</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="43"/>
        <source>&amp;Play/Pause</source>
        <translation>&amp;Reproducir/Pausar</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="43"/>
        <source>Space</source>
        <translation>Espacio</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="44"/>
        <source>J</source>
        <translation>J</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="44"/>
        <source>&amp;Jump to Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="45"/>
        <source>&amp;Repeat Playlist</source>
        <translation>&amp;Repetir la lista</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="45"/>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="46"/>
        <source>&amp;Repeat Track</source>
        <translation>&amp;Repetir pista</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="46"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="47"/>
        <source>&amp;Shuffle</source>
        <translation>&amp;Revolver</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="47"/>
        <source>S</source>
        <translation>S</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="48"/>
        <source>&amp;No Playlist Advance</source>
        <translation>&amp;No avanzar en la lista</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="49"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="50"/>
        <source>&amp;Stop After Selected</source>
        <translation>&amp;Parar tras los seleccionados</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="51"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="52"/>
        <source>&amp;Clear Queue</source>
        <translation>&amp;Limpiar la Cola</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="52"/>
        <source>Alt+Q</source>
        <translation>Alt+Q</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="54"/>
        <source>Show Playlist</source>
        <translation>Mostrar la lista</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="54"/>
        <source>Alt+E</source>
        <translation>Alt+E</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="55"/>
        <source>Show Equalizer</source>
        <translation>Mostrar el ecualizador</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="55"/>
        <source>Alt+G</source>
        <translation>Alt+G</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="56"/>
        <source>Always on Top</source>
        <translation>Siempre encima</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="57"/>
        <source>Put on All Workspaces</source>
        <translation>Ver en todos los escritorios</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="58"/>
        <source>Double Size</source>
        <translation>Tamaño doble</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="58"/>
        <source>Meta+D</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="60"/>
        <source>&amp;Add File</source>
        <translation>&amp;Añadir archivo</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="60"/>
        <source>F</source>
        <translation>F</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="61"/>
        <source>&amp;Add Directory</source>
        <translation>&amp;Añadir directorio</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="61"/>
        <source>D</source>
        <translation>D</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="62"/>
        <source>&amp;Add Url</source>
        <translation>&amp;Añadir URL</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="62"/>
        <source>U</source>
        <translation>U</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="63"/>
        <source>&amp;Remove Selected</source>
        <translation>&amp;Eliminar los seleccionados</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="64"/>
        <source>Del</source>
        <translation>Supr</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="65"/>
        <source>&amp;Remove All</source>
        <translation>&amp;Eliminar todo</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="66"/>
        <source>&amp;Remove Unselected</source>
        <translation>&amp;Eliminar los no seleccionados</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="68"/>
        <source>Remove unavailable files</source>
        <translation>Eliminar los archivos no disponibles</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="70"/>
        <source>Remove duplicates</source>
        <translation>Eliminar los duplicados</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="71"/>
        <source>&amp;Queue Toggle</source>
        <translation>&amp;Cambiar de cola</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="71"/>
        <source>Q</source>
        <translation>Q</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="72"/>
        <source>Invert Selection</source>
        <translation>Invertir la selección</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="73"/>
        <source>&amp;Select None</source>
        <translation>&amp;No seleccionar nada</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="74"/>
        <source>&amp;Select All</source>
        <translation>&amp;Seleccionar todo</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="75"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="76"/>
        <source>&amp;View Track Details</source>
        <translation>&amp;Ver detalles de la pista</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="76"/>
        <source>Alt+I</source>
        <translation>Alt+I</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="78"/>
        <source>&amp;New List</source>
        <translation>&amp;Lista nueva</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="78"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="79"/>
        <source>&amp;Delete List</source>
        <translation>&amp;Borrar la lista</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="79"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="80"/>
        <source>&amp;Load List</source>
        <translation>&amp;Cargar una lista</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="80"/>
        <source>O</source>
        <translation>O</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="81"/>
        <source>&amp;Save List</source>
        <translation>&amp;Guardar la lista</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="81"/>
        <source>Shift+S</source>
        <translation>Shift+S</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="82"/>
        <source>&amp;Select Next Playlist</source>
        <translation>&amp;Seleccionar la lista siguiente</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="83"/>
        <source>Ctrl+PgDown</source>
        <translation>Ctrl+AvPág</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="84"/>
        <source>&amp;Select Previous Playlist</source>
        <translation>&amp;Seleccionar la lista anterior</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="85"/>
        <source>Ctrl+PgUp</source>
        <translation>Ctrl+RePág</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="86"/>
        <source>&amp;Show Playlists</source>
        <translation>&amp;Mostrar las listas</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="87"/>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="89"/>
        <source>&amp;Settings</source>
        <translation>&amp;Configuración</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="89"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="90"/>
        <source>&amp;About</source>
        <translation>&amp;Acerca de</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="91"/>
        <source>&amp;About Qt</source>
        <translation>&amp;Acerca de Qt</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="92"/>
        <source>&amp;Exit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="92"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
</context>
<context>
    <name>EqWidget</name>
    <message>
        <location filename="../eqwidget.cpp" line="157"/>
        <location filename="../eqwidget.cpp" line="178"/>
        <source>preset</source>
        <translation>preprogramado</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="264"/>
        <source>&amp;Load/Delete</source>
        <translation>&amp;Cargar/Eliminar</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="266"/>
        <source>&amp;Save Preset</source>
        <translation>&amp;Guardar preprogramado</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="268"/>
        <source>&amp;Save Auto-load Preset</source>
        <translation>&amp;Guardar preprogramado autocargable</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="273"/>
        <source>&amp;Clear</source>
        <translation>&amp;Limpiar</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="302"/>
        <source>Saving Preset</source>
        <translation>Guardando preprogramado</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="303"/>
        <source>Preset name:</source>
        <translation>Nombre del preprogramado:</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="304"/>
        <source>preset #</source>
        <translation>Preprogramado nº</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="270"/>
        <source>&amp;Import</source>
        <translation>&amp;Importar</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="44"/>
        <source>Equalizer</source>
        <translation>Ecualizador</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="395"/>
        <source>Import Preset</source>
        <translation>Importar preprogramado</translation>
    </message>
</context>
<context>
    <name>HotkeyEditor</name>
    <message>
        <location filename="../forms/hotkeyeditor.ui" line="27"/>
        <source>Action</source>
        <translation type="unfinished">Acción</translation>
    </message>
    <message>
        <location filename="../forms/hotkeyeditor.ui" line="32"/>
        <source>Shortcut</source>
        <translation type="unfinished">Atajo</translation>
    </message>
    <message>
        <location filename="../forms/hotkeyeditor.ui" line="40"/>
        <source>Change shortcut...</source>
        <translation type="unfinished">Cambiar atajo...</translation>
    </message>
    <message>
        <location filename="../hotkeyeditor.cpp" line="55"/>
        <source>Playback</source>
        <translation type="unfinished">Reproducción</translation>
    </message>
    <message>
        <location filename="../hotkeyeditor.cpp" line="61"/>
        <source>View</source>
        <translation type="unfinished">Ver</translation>
    </message>
    <message>
        <location filename="../hotkeyeditor.cpp" line="67"/>
        <source>Playlist</source>
        <translation type="unfinished">Lista de reproducción</translation>
    </message>
    <message>
        <location filename="../hotkeyeditor.cpp" line="73"/>
        <source>Misc</source>
        <translation type="unfinished">Varios</translation>
    </message>
</context>
<context>
    <name>MainDisplay</name>
    <message>
        <location filename="../display.cpp" line="57"/>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="61"/>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="64"/>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="67"/>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="70"/>
        <source>Next</source>
        <translation>Siguiente</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="73"/>
        <source>Add file</source>
        <translation>Añadir archivo</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="80"/>
        <source>Equalizer</source>
        <translation>Ecualizador</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="83"/>
        <source>Playlist</source>
        <translation>Lista de reproducción</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="88"/>
        <source>Repeat playlist</source>
        <translation>Repetir la lista de reproducción</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="91"/>
        <source>Shuffle</source>
        <translation>Revolver</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="101"/>
        <source>Volume</source>
        <translation>Volumen</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="107"/>
        <source>Balance</source>
        <translation>Balance</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="296"/>
        <source>Volume: %1%</source>
        <translation>Volumen: %1%</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="300"/>
        <source>Balance: %1% right</source>
        <translation>Balance: %1% derecha</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="302"/>
        <source>Balance: %1% left</source>
        <translation>Balance: %1% izquierda</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="304"/>
        <source>Balance: center</source>
        <translation>Balance: centro</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="315"/>
        <source>Seek to: %1</source>
        <translation>Ir hasta: %1</translation>
    </message>
</context>
<context>
    <name>MainVisual</name>
    <message>
        <location filename="../mainvisual.cpp" line="243"/>
        <source>Visualization Mode</source>
        <translation>Modo de visualización</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="246"/>
        <source>Analyzer</source>
        <translation>Analizador</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="247"/>
        <source>Scope</source>
        <translation>Osciloscopio</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="248"/>
        <source>Off</source>
        <translation>Apagado</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="255"/>
        <source>Analyzer Mode</source>
        <translation>Modo del analizador</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="258"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="259"/>
        <source>Fire</source>
        <translation>Fuego</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="260"/>
        <source>Vertical Lines</source>
        <translation>Líneas verticales</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="261"/>
        <source>Lines</source>
        <translation>Líneas</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="262"/>
        <source>Bars</source>
        <translation>Barras</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="275"/>
        <source>Peaks</source>
        <translation>Picos</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="279"/>
        <source>Refresh Rate</source>
        <translation>Velocidad de actualización</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="282"/>
        <source>50 fps</source>
        <translation>50 fps</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="283"/>
        <source>25 fps</source>
        <translation>25 fps</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="284"/>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="285"/>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="292"/>
        <source>Analyzer Falloff</source>
        <translation>Caída del analizador</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="295"/>
        <location filename="../mainvisual.cpp" line="309"/>
        <source>Slowest</source>
        <translation>Muy lenta</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="296"/>
        <location filename="../mainvisual.cpp" line="310"/>
        <source>Slow</source>
        <translation>Lenta</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="297"/>
        <location filename="../mainvisual.cpp" line="311"/>
        <source>Medium</source>
        <translation>Media</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="298"/>
        <location filename="../mainvisual.cpp" line="312"/>
        <source>Fast</source>
        <translation>Rápida</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="299"/>
        <location filename="../mainvisual.cpp" line="313"/>
        <source>Fastest</source>
        <translation>Muy rápida</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="306"/>
        <source>Peaks Falloff</source>
        <translation>Caída de picos</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="319"/>
        <source>Background</source>
        <translation>Fondo</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="320"/>
        <source>Transparent</source>
        <translation>Transparente</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="318"/>
        <source>Appearance</source>
        <translation type="unfinished">Aspecto</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="319"/>
        <source>Shortcuts</source>
        <translation type="unfinished">Atajos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="381"/>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="389"/>
        <source>Playlist</source>
        <translation>Lista de reproducción</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="409"/>
        <source>Tools</source>
        <translation>Herramientas</translation>
    </message>
</context>
<context>
    <name>PlayList</name>
    <message>
        <location filename="../playlist.cpp" line="178"/>
        <source>&amp;Copy Selection To</source>
        <translation>&amp;Copiar la selección a</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="207"/>
        <source>Sort List</source>
        <translation>Ordenar la lista</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="210"/>
        <location filename="../playlist.cpp" line="253"/>
        <source>By Title</source>
        <translation>Por título</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="214"/>
        <location filename="../playlist.cpp" line="257"/>
        <source>By Album</source>
        <translation>Por album</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="218"/>
        <location filename="../playlist.cpp" line="261"/>
        <source>By Disc Number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="222"/>
        <location filename="../playlist.cpp" line="265"/>
        <source>By Artist</source>
        <translation>Por intérprete</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="226"/>
        <location filename="../playlist.cpp" line="269"/>
        <source>By Filename</source>
        <translation>Por nombre de archivo</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="230"/>
        <location filename="../playlist.cpp" line="273"/>
        <source>By Path + Filename</source>
        <translation>Por ruta + nombre</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="234"/>
        <location filename="../playlist.cpp" line="277"/>
        <source>By Date</source>
        <translation>Por fecha</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="242"/>
        <location filename="../playlist.cpp" line="285"/>
        <source>By File Creation Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="250"/>
        <source>Sort Selection</source>
        <translation>Ordenar la selección</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="293"/>
        <source>Randomize List</source>
        <translation>Lista aleatoria</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="295"/>
        <source>Reverse List</source>
        <translation>Invertir la lista</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="565"/>
        <source>&amp;New PlayList</source>
        <translation>&amp;Lista nueva</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="238"/>
        <location filename="../playlist.cpp" line="281"/>
        <source>By Track Number</source>
        <translation>Por número de pista</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="53"/>
        <source>Playlist</source>
        <translation>Lista de reproducción</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="302"/>
        <source>Actions</source>
        <translation>Acciones</translation>
    </message>
</context>
<context>
    <name>PlayListBrowser</name>
    <message>
        <location filename="../forms/playlistbrowser.ui" line="14"/>
        <source>Playlist Browser</source>
        <translation>Navegador de listas de reproducción</translation>
    </message>
    <message>
        <location filename="../forms/playlistbrowser.ui" line="45"/>
        <source>New</source>
        <translation>Nueva</translation>
    </message>
    <message>
        <location filename="../forms/playlistbrowser.ui" line="52"/>
        <location filename="../playlistbrowser.cpp" line="40"/>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <location filename="../forms/playlistbrowser.ui" line="69"/>
        <location filename="../forms/playlistbrowser.ui" line="79"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../playlistbrowser.cpp" line="39"/>
        <source>Rename</source>
        <translation>Renombrar</translation>
    </message>
</context>
<context>
    <name>PlayListSelector</name>
    <message>
        <location filename="../playlistselector.cpp" line="50"/>
        <source>&amp;Load</source>
        <translation>&amp;Cargar</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="51"/>
        <source>&amp;Save As...</source>
        <translation>&amp;Guardar como...</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="53"/>
        <source>Rename</source>
        <translation>Renombrar</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="54"/>
        <source>&amp;Delete</source>
        <translation>&amp;Borrar</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="125"/>
        <source>Rename Playlist</source>
        <translation>Renombrar lista</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="125"/>
        <source>Playlist name:</source>
        <translation>Nombre de la lista:</translation>
    </message>
</context>
<context>
    <name>PopupSettings</name>
    <message>
        <location filename="../forms/popupsettings.ui" line="14"/>
        <source>Popup Information Settings</source>
        <translation>Configuración de información emergente</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="75"/>
        <source>Show cover</source>
        <translation>Mostrar carátula</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="115"/>
        <source>Transparency:</source>
        <translation>Transparencia:</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="145"/>
        <source>Delay:</source>
        <translation>Retardo:</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="178"/>
        <source>ms</source>
        <translation>ms</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="89"/>
        <source>Cover size:</source>
        <translation>Tamaño de la carátula:</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="29"/>
        <source>Template</source>
        <translation>Plantilla</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="58"/>
        <source>Reset</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="65"/>
        <source>Insert</source>
        <translation>Insertar</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="62"/>
        <source>Artist</source>
        <translation>Intérprete</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="63"/>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="64"/>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="65"/>
        <source>Track number</source>
        <translation>Número de pista</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="66"/>
        <source>Two-digit track number</source>
        <translation>Número de pista con dos cifras</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="67"/>
        <source>Genre</source>
        <translation>Género</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="68"/>
        <source>Comment</source>
        <translation>Comentario</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="69"/>
        <source>Composer</source>
        <translation>Compositor</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="70"/>
        <source>Duration</source>
        <translation>Duración</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="71"/>
        <source>Disc number</source>
        <translation>Número de disco</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="72"/>
        <source>File name</source>
        <translation>Nombre del archivo</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="73"/>
        <source>File path</source>
        <translation>Ruta del archivo</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="74"/>
        <source>Year</source>
        <translation>Año</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="75"/>
        <source>Condition</source>
        <translation>Condición</translation>
    </message>
</context>
<context>
    <name>PresetEditor</name>
    <message>
        <location filename="../forms/preseteditor.ui" line="14"/>
        <source>Preset Editor</source>
        <translation>Editor de preprogamados</translation>
    </message>
    <message>
        <location filename="../forms/preseteditor.ui" line="77"/>
        <source>Load</source>
        <translation>Cargar</translation>
    </message>
    <message>
        <location filename="../forms/preseteditor.ui" line="84"/>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <location filename="../forms/preseteditor.ui" line="36"/>
        <source>Preset</source>
        <translation>Preprogramado</translation>
    </message>
    <message>
        <location filename="../forms/preseteditor.ui" line="52"/>
        <source>Auto-preset</source>
        <translation>Automático</translation>
    </message>
</context>
<context>
    <name>ShortcutDialog</name>
    <message>
        <location filename="../forms/shortcutdialog.ui" line="14"/>
        <source>Change Shortcut</source>
        <translation>Cambiar atajo</translation>
    </message>
    <message>
        <location filename="../forms/shortcutdialog.ui" line="29"/>
        <source>Press the key combination you want to assign</source>
        <translation>Pulse la combinación de teclas que quiere asignar</translation>
    </message>
    <message>
        <location filename="../forms/shortcutdialog.ui" line="52"/>
        <source>Clear</source>
        <translation>Borrar</translation>
    </message>
</context>
<context>
    <name>SkinnedFactory</name>
    <message>
        <location filename="../skinnedfactory.cpp" line="31"/>
        <source>Skinned User Interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../skinnedfactory.cpp" line="44"/>
        <source>About Qmmp Skinned User Interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../skinnedfactory.cpp" line="45"/>
        <source>Qmmp Skinned User Interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../skinnedfactory.cpp" line="46"/>
        <source>Simple user interface with Winamp-2.x/XMMS skins support</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../skinnedfactory.cpp" line="47"/>
        <source>Written by:
Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../skinnedfactory.cpp" line="50"/>
        <source>Artwork:
Andrey Adreev &lt;andreev00@gmail.com&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SkinnedSettings</name>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="24"/>
        <source>Skins</source>
        <translation type="unfinished">Pieles</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="55"/>
        <source>Add...</source>
        <translation type="unfinished">Añadir...</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="68"/>
        <source>Refresh</source>
        <translation type="unfinished">Actualizar</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="89"/>
        <location filename="../forms/skinnedsettings.ui" line="95"/>
        <source>View</source>
        <translation type="unfinished">Ver</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="101"/>
        <source>Hide on close</source>
        <translation type="unfinished">Esconder al cerrar</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="108"/>
        <source>Start hidden</source>
        <translation type="unfinished">Iniciar oculto</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="115"/>
        <source>Use skin cursors</source>
        <translation type="unfinished">Usar pieles en cursor</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="131"/>
        <source>Fonts</source>
        <translation type="unfinished">Fuentes</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="149"/>
        <source>Player:</source>
        <translation type="unfinished">Reproductor: </translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="171"/>
        <location filename="../forms/skinnedsettings.ui" line="219"/>
        <source>???</source>
        <translation type="unfinished">???</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="178"/>
        <location filename="../forms/skinnedsettings.ui" line="226"/>
        <source>...</source>
        <translation type="unfinished">...</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="197"/>
        <source>Playlist:</source>
        <translation type="unfinished">Lista de reproducción: </translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="233"/>
        <source>Use bitmap font if available</source>
        <translation type="unfinished">Usar fuente bitmap si está disponible</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="243"/>
        <source>Transparency</source>
        <translation type="unfinished">Transparencia</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="249"/>
        <source>Main window</source>
        <translation type="unfinished">Ventana principal</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="272"/>
        <location filename="../forms/skinnedsettings.ui" line="296"/>
        <location filename="../forms/skinnedsettings.ui" line="320"/>
        <source>0</source>
        <translation type="unfinished">0</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="279"/>
        <source>Equalizer</source>
        <translation type="unfinished">Ecualizador</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="303"/>
        <source>Playlist</source>
        <translation type="unfinished">Lista de reproducción</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="344"/>
        <source>Miscellaneous</source>
        <translation type="unfinished">Varios</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="350"/>
        <source>Song Display</source>
        <translation type="unfinished">Mostrar la canción</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="356"/>
        <source>Show protocol</source>
        <translation type="unfinished">Motrar protocolo</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="363"/>
        <source>Show song numbers</source>
        <translation type="unfinished">Mostrar los números de canción</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="387"/>
        <source>Show playlists</source>
        <translation type="unfinished">Mostrar la lista de reproducción</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="394"/>
        <source>Show popup information</source>
        <translation type="unfinished">Mostrar información emergente</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="406"/>
        <source>Edit template</source>
        <translation type="unfinished">Editar la plantilla</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="430"/>
        <source>Playlist separator:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="468"/>
        <source>Show &apos;New Playlist&apos; button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="380"/>
        <source>Show anchor</source>
        <translation type="unfinished">Mostrar ancla</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="373"/>
        <source>Align song numbers</source>
        <translation type="unfinished">Alinear los números de canción</translation>
    </message>
    <message>
        <location filename="../skinnedsettings.cpp" line="101"/>
        <source>Select Skin Files</source>
        <translation type="unfinished">Seleccionar archivos de pieles</translation>
    </message>
    <message>
        <location filename="../skinnedsettings.cpp" line="102"/>
        <source>Skin files</source>
        <translation type="unfinished">Archivos de pieles</translation>
    </message>
    <message>
        <location filename="../skinnedsettings.cpp" line="150"/>
        <source>Unarchived skin</source>
        <translation type="unfinished">Piel no archivada</translation>
    </message>
    <message>
        <location filename="../skinnedsettings.cpp" line="181"/>
        <source>Archived skin</source>
        <translation type="unfinished">Piel archivada</translation>
    </message>
</context>
<context>
    <name>TextScroller</name>
    <message>
        <location filename="../textscroller.cpp" line="53"/>
        <source>Autoscroll Songname</source>
        <translation>Autodesplazar el nombre de la canción</translation>
    </message>
    <message>
        <location filename="../textscroller.cpp" line="54"/>
        <source>Transparent Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../textscroller.cpp" line="123"/>
        <source>Buffering: %1%</source>
        <translation>Cargando: %1%</translation>
    </message>
</context>
<context>
    <name>VisualMenu</name>
    <message>
        <location filename="../visualmenu.cpp" line="26"/>
        <source>Visualization</source>
        <translation>Visualización</translation>
    </message>
</context>
</TS>
